==> codelite_2.2.0.3681+dfsg.orig.tar.gz: codelite-2.2.0.3681+dfsg/Copyright/copyright.h <==
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// copyright            : (C) 2008 by Eran Ifrah                            
// file name            : copyright.h              
//                                                                          
// -------------------------------------------------------------------------
// A                                                                        
//              _____           _      _     _ _                            
//             /  __ \         | |    | |   (_) |                           
//             | /  \/ ___   __| | ___| |    _| |_ ___                      
//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )                     
//             | \__/\ (_) | (_| |  __/ |___| | ||  __/                     
//              \____/\___/ \__,_|\___\_____/_|\__\___|                     
//                                                                          
//                                                  F i l e                 
//                                                                          
//    This program is free software; you can redistribute it and/or modify  
//    it under the terms of the GNU General Public License as published by  
//    the Free Software Foundation; either version 2 of the License, or     
//    (at your option) any later version.                                   
//                                                                          
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
 #ifndef __Copyright__
#define __Copyright__

#include "plugin.h"
class wxMenuItem;
class Copyright : public IPlugin
{
	wxEvtHandler *m_topWin;
	wxMenuItem* m_projectSepItem;
	wxMenuItem* m_workspaceSepItem;
	
protected:
	bool Validate(wxString &content);
	void MassUpdate(const std::vector<wxFileName> &filtered_files, const wxString &content);
	
public:
	Copyright(IManager *manager);
	~Copyright();
	
	//--------------------------------------------
	//Abstract methods
	//--------------------------------------------
	virtual wxToolBar *CreateToolBar(wxWindow *parent);
	virtual void CreatePluginMenu(wxMenu *pluginsMenu);
	virtual void HookPopupMenu(wxMenu *menu, MenuType type);
	virtual void UnHookPopupMenu(wxMenu *menu, MenuType type);
	virtual void UnPlug();
	
	// event handlers
	void OnOptions(wxCommandEvent &e);
	void OnInsertCopyrights(wxCommandEvent &e);
	void OnBatchInsertCopyrights(wxCommandEvent &e);
	void OnProjectInsertCopyrights(wxCommandEvent &e);
};

#endif //Copyright

==> codelite_2.6.0.4189~dfsg.orig.tar.gz: codelite-2.6.0.4189~dfsg/Copyright/copyright.h <==
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// copyright            : (C) 2008 by Eran Ifrah                            
// file name            : copyright.h              
//                                                                          
// -------------------------------------------------------------------------
// A                                                                        
//              _____           _      _     _ _                            
//             /  __ \         | |    | |   (_) |                           
//             | /  \/ ___   __| | ___| |    _| |_ ___                      
//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )                     
//             | \__/\ (_) | (_| |  __/ |___| | ||  __/                     
//              \____/\___/ \__,_|\___\_____/_|\__\___|                     
//                                                                          
//                                                  F i l e                 
//                                                                          
//    This program is free software; you can redistribute it and/or modify  
//    it under the terms of the GNU General Public License as published by  
//    the Free Software Foundation; either version 2 of the License, or     
//    (at your option) any later version.                                   
//                                                                          
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
 #ifndef __Copyright__
#define __Copyright__

#include "plugin.h"
class wxMenuItem;
class Copyright : public IPlugin
{
	wxEvtHandler *m_topWin;
	wxMenuItem* m_projectSepItem;
	wxMenuItem* m_workspaceSepItem;
	
protected:
	bool Validate(wxString &content);
	void MassUpdate(const std::vector<wxFileName> &filtered_files, const wxString &content);
	
public:
	Copyright(IManager *manager);
	~Copyright();
	
	//--------------------------------------------
	//Abstract methods
	//--------------------------------------------
	virtual clToolBar *CreateToolBar(wxWindow *parent);
	virtual void CreatePluginMenu(wxMenu *pluginsMenu);
	virtual void HookPopupMenu(wxMenu *menu, MenuType type);
	virtual void UnHookPopupMenu(wxMenu *menu, MenuType type);
	virtual void UnPlug();
	
	// event handlers
	void OnOptions(wxCommandEvent &e);
	void OnInsertCopyrights(wxCommandEvent &e);
	void OnBatchInsertCopyrights(wxCommandEvent &e);
	void OnProjectInsertCopyrights(wxCommandEvent &e);
};

#endif //Copyright
